@@ -5,7 +5,7 @@ from __future__ import print_function
 
 import numpy as np
 from .association import *
-from person_counter.yolov5.utils.general import xywh2xyxy
+from ...yolov5.utils.general import xywh2xyxy
 
 
 def k_previous_obs(observations, cur_age, k):
@@ -174,7 +174,8 @@ ASSO_FUNCS = {  "iou": iou_batch,
                 "giou": giou_batch,
                 "ciou": ciou_batch,
                 "diou": diou_batch,
-                "ct_dist": ct_dist}
+                "ct_dist": ct_dist
+            }
 
 
 class OCSort(object):
